def example():
    print("Hello World!")
    return 0

#define a class with a method that takes a list of numbers as an argument and returns the sum of all numbers in the list
class Sum:
    def __init__(self, nums):
        self.nums = nums
    def sum(self):
        return sum(self.nums)



from setuptools import setup, find_packages


with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

setup(
    name='raya_os',
    packages=find_packages(),
    version='0.0.4',
    license='MIT',
    description='Raya OS skelaton',
    long_description=readme,
    author='Ofir Ozeri',
    author_email='ofiro@unlimited-robotics.com',
    url='', 
    python_requires=">=3.8",
    install_requires=[
        'rayasdk'
    ]  
)



from raya.
class MotionController(BaseController):


    async def set_velocity(self, x_velocity: float, y_velocity: float, 
                           angular_velocity: float, duration: float, 
                           callback=None, wait=False, 
                           ang_unit: ANG_UNIT = ANG_UNIT.DEG):
        pass

    
    async def move_linear(self, distance: float, x_velocity: float, 
                          callback=None, wait=False):
        pass


    async def rotate(self, angle: float, angular_velocity: float, 
                           callback=None, wait=False, 
                           ang_unit: ANG_UNIT = ANG_UNIT.DEG):
        pass


    async def await_until_stop(self):
        pass


    async def cancel_motion(self):
        pass

    def is_moving(self):
        pass